@@ -1,12 +1,9 @@
 package MooseX::NonMoose::InsideOut;
-BEGIN {
-  $MooseX::NonMoose::InsideOut::AUTHORITY = 'cpan:DOY';
-}
-{
-  $MooseX::NonMoose::InsideOut::VERSION = '0.25';
-}
+
 use Moose::Exporter;
+
 # ABSTRACT: easy subclassing of non-Moose non-hashref classes
+our $VERSION = '0.27'; # VERSION
 
 
 my ($import, $unimport, $init_meta) = Moose::Exporter->build_import_methods(
@@ -34,13 +31,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 MooseX::NonMoose::InsideOut - easy subclassing of non-Moose non-hashref classes
 
 =head1 VERSION
 
-version 0.25
+version 0.27
 
 =head1 SYNOPSIS
 
@@ -75,11 +74,13 @@ version 0.25
 
 =head1 AUTHOR
 
-Jesse Luehrs <doy@tozt.net>
+Original author: Jesse Luehrs E<lt>doy@tozt.netE<gt>
+
+Current maintainer: Graham Ollis E<lt>plicease@cpan.orgE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Jesse Luehrs.
+This software is copyright (c) 2009-2025 by Jesse Luehrs.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
